# onnxds

This project partially extends onnx by creating a dataset structure similar to tensorflow_datasets.

# tfgen_dataset

This tool serializes datasets in tensorflow_datasets to onnx TensorProto objects.
This aims to take all the benefits of datasets without relying on installing tensorflow and its dependencies.
